==> nextcloud-24.0.11.tgz: nextcloud/apps/encryption/l10n/th.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "รหัสผ่านของคีย์การกู้คืนขาดหาย",
    "Please repeat the recovery key password" : "กรุณาใส่รหัสผ่านของคีย์การกู้คืนอีกครั้ง",
    "Repeated recovery key password does not match the provided recovery key password" : "รหัสผ่านของรหัสกู้คืนที่ใส่ซ้ำ ไม่ตรงกับรหัสผ่านของรหัสกู้คืนที่ใส่ไปก่อนหน้านี้",
    "Recovery key successfully enabled" : "เปิดใช้งานคีย์การกู้คืนเรียบร้อยแล้ว",
    "Could not enable recovery key. Please check your recovery key password!" : "ไม่สามารถเปิดใช้งานรหัสกู้คืน กรุณาตรวจสอบรหัสผ่านสำหรับรหัสกู้คืนของคุณ!",
    "Recovery key successfully disabled" : "ปิดใช้งานคีย์การกู้คืนเรียบร้อยแล้ว",
    "Could not disable recovery key. Please check your recovery key password!" : "ไม่สามารถปิดใช้งานคีย์การกู้คืน กรุณาตรวจสอบรหัสผ่านสำหรับคีย์การกู้คืนของคุณ!",
    "Missing parameters" : "ค่าพารามิเตอร์ขาดหาย",
    "Please provide the old recovery password" : "โปรดระบุรหัสผ่านการกู้คืนเก่า",
    "Please provide a new recovery password" : "โปรดระบุรหัสผ่านการกู้คืนใหม่",
    "Please repeat the new recovery password" : "โปรดระบุรหัสผ่านกู้คืนใหม่อีกครั้ง",
    "Password successfully changed." : "เปลี่ยนรหัสผ่านเรียบร้อยแล้ว",
    "Could not change the password. Maybe the old password was not correct." : "ไม่สามารถเปลี่ยนรหัสผ่าน รหัสผ่านเดิมอาจไม่ถูกต้อง",
    "Recovery Key disabled" : "คีย์การกู้คืนถูกปิดใช้งาน",
    "Recovery Key enabled" : "เปิดการใช้งานคีย์การกู้คืน",
    "Could not enable the recovery key, please try again or contact your administrator" : "ไม่สามารถเปิดใช้คีย์การกู้คืน โปรดลองอีกครั้งหรือติดต่อผู้ดูแลระบบ",
    "Could not update the private key password." : "ไม่สามารถอัปเดตรหัสผ่านคีย์ส่วนตัว",
    "The old password was not correct, please try again." : "รหัสผ่านเดิมไม่ถูกต้อง โปรดลองอีกครั้ง",
    "The current log-in password was not correct, please try again." : "รหัสผ่านเข้าสู่ระบบปัจจุบันไม่ถูกต้อง โปรดลองอีกครั้ง",
    "Private key password successfully updated." : "อัปเดตรหัสผ่านของคีย์ส่วนตัวเรียบร้อยแล้ว",
    "Bad Signature" : "ลายเซ็นไม่ดี",
    "Missing Signature" : "ลายเซ็นขาดหายไป",
    "one-time password for server-side-encryption" : "รหัสผ่านใช้ครั้งเดียว สำหรับการเข้ารหัสฝั่งเซิร์ฟเวอร์",
    "The share will expire on %s." : "การแชร์จะหมดอายุในวันที่ %s",
    "Cheers!" : "ไชโย!",
    "Encrypt the home storage" : "การเข้ารหัสพื้นที่จัดเก็บโฮม",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "การเปิดใช้งานตัวเลือกนี้จะเข้ารหัสไฟล์ทั้งหมดที่เก็บไว้ในพื้นที่จัดเก็บข้อมูลหลัก มิฉะนั้นจะเข้ารหัสเฉพาะไฟล์บนพื้นที่จัดเก็บข้อมูลภายนอก",
    "Enable recovery key" : "เปิดใช้งานคีย์การกู้คืน",
    "Disable recovery key" : "ปิดใช้งานคีย์การกู้คืน",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "คีย์การกู้คืนเป็นคีย์เข้ารหัสเพิ่มเติมที่ใช้ในการเข้ารหัสไฟล์ ซึ่งจะทำให้สามารถกู้คืนไฟล์ของผู้ใช้ที่ลืมรหัสผ่านได้",
    "Recovery key password" : "รหัสผ่านสำหรับรหัสกู้คืน",
    "Repeat recovery key password" : "ใส่รหัสผ่านของคีย์การกู้คืนอีกครั้ง",
    "Change recovery key password:" : "เปลี่ยนรหัสผ่านของคีย์การกู้คืน:",
    "Old recovery key password" : "รหัสผ่านของคีย์การกู้คืนเก่า",
    "New recovery key password" : "รหัสผ่านของคีย์การกู้คืนใหม่",
    "Repeat new recovery key password" : "ใส่รหัสผ่านของคีย์การกู้คืนใหม่อีกครั้ง",
    "Change Password" : "เปลี่ยนรหัสผ่าน",
    "Your private key password no longer matches your log-in password." : "รหัสผ่านคีย์ส่วนตัวของคุณ ไม่ตรงกับรหัสผ่านที่ใช้เข้าสู่ระบบของคุณอีกต่อไป",
    "Set your old private key password to your current log-in password:" : "ตั้งรหัสผ่านคีย์ส่วนตัวเก่าของคุณเป็นรหัสผ่านเข้าสู่ระบบปัจจุบันของคุณ:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "ถ้าคุณลืมรหัสผ่านเก่าของคุณ คุณสามารถขอให้ผู้ดูแลระบบกู้คืนไฟล์ของคุณ",
    "Old log-in password" : "รหัสผ่านเข้าสู่ระบบเดิม",
    "Current log-in password" : "รหัสผ่านเข้าสู่ระบบปัจจุบัน",
    "Update Private Key Password" : "อัปเดตรหัสผ่านคีย์ส่วนตัว",
    "Enable password recovery:" : "เปิดใช้งานการกู้คืนด้วยรหัสผ่าน:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "การเปิดใช้งานตัวเลือกนี้จะช่วยให้คุณสามารถเข้าถึงไฟล์ของคุณที่เข้ารหัสไว้ ในกรณีที่คุณลืมรหัสผ่าน",
    "Enabled" : "เปิดใช้งาน",
    "Disabled" : "ปิดใช้งาน"
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.2.tgz: nextcloud/apps/encryption/l10n/th.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "รหัสผ่านของคีย์การกู้คืนขาดหาย",
    "Please repeat the recovery key password" : "กรุณาใส่รหัสผ่านของคีย์การกู้คืนอีกครั้ง",
    "Repeated recovery key password does not match the provided recovery key password" : "รหัสผ่านของรหัสกู้คืนที่ใส่ซ้ำ ไม่ตรงกับรหัสผ่านของรหัสกู้คืนที่ใส่ไปก่อนหน้านี้",
    "Recovery key successfully enabled" : "เปิดใช้งานคีย์การกู้คืนเรียบร้อยแล้ว",
    "Could not enable recovery key. Please check your recovery key password!" : "ไม่สามารถเปิดใช้งานรหัสกู้คืน กรุณาตรวจสอบรหัสผ่านสำหรับรหัสกู้คืนของคุณ!",
    "Recovery key successfully disabled" : "ปิดใช้งานคีย์การกู้คืนเรียบร้อยแล้ว",
    "Could not disable recovery key. Please check your recovery key password!" : "ไม่สามารถปิดใช้งานคีย์การกู้คืน กรุณาตรวจสอบรหัสผ่านสำหรับคีย์การกู้คืนของคุณ!",
    "Missing parameters" : "ค่าพารามิเตอร์ขาดหาย",
    "Please provide the old recovery password" : "โปรดระบุรหัสผ่านการกู้คืนเก่า",
    "Please provide a new recovery password" : "โปรดระบุรหัสผ่านการกู้คืนใหม่",
    "Please repeat the new recovery password" : "โปรดระบุรหัสผ่านกู้คืนใหม่อีกครั้ง",
    "Password successfully changed." : "เปลี่ยนรหัสผ่านเรียบร้อยแล้ว",
    "Could not change the password. Maybe the old password was not correct." : "ไม่สามารถเปลี่ยนรหัสผ่าน รหัสผ่านเดิมอาจไม่ถูกต้อง",
    "Recovery Key disabled" : "คีย์การกู้คืนถูกปิดใช้งาน",
    "Recovery Key enabled" : "เปิดการใช้งานคีย์การกู้คืน",
    "Could not enable the recovery key, please try again or contact your administrator" : "ไม่สามารถเปิดใช้คีย์การกู้คืน โปรดลองอีกครั้งหรือติดต่อผู้ดูแลระบบ",
    "Could not update the private key password." : "ไม่สามารถอัปเดตรหัสผ่านคีย์ส่วนตัว",
    "The old password was not correct, please try again." : "รหัสผ่านเดิมไม่ถูกต้อง โปรดลองอีกครั้ง",
    "The current log-in password was not correct, please try again." : "รหัสผ่านเข้าสู่ระบบปัจจุบันไม่ถูกต้อง โปรดลองอีกครั้ง",
    "Private key password successfully updated." : "อัปเดตรหัสผ่านของคีย์ส่วนตัวเรียบร้อยแล้ว",
    "Bad Signature" : "ลายเซ็นไม่ดี",
    "Missing Signature" : "ลายเซ็นขาดหายไป",
    "one-time password for server-side-encryption" : "รหัสผ่านใช้ครั้งเดียว สำหรับการเข้ารหัสฝั่งเซิร์ฟเวอร์",
    "Encrypt the home storage" : "การเข้ารหัสพื้นที่จัดเก็บโฮม",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "การเปิดใช้งานตัวเลือกนี้จะเข้ารหัสไฟล์ทั้งหมดที่เก็บไว้ในพื้นที่จัดเก็บข้อมูลหลัก มิฉะนั้นจะเข้ารหัสเฉพาะไฟล์บนพื้นที่จัดเก็บข้อมูลภายนอก",
    "Enable recovery key" : "เปิดใช้งานคีย์การกู้คืน",
    "Disable recovery key" : "ปิดใช้งานคีย์การกู้คืน",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "คีย์การกู้คืนเป็นคีย์เข้ารหัสเพิ่มเติมที่ใช้ในการเข้ารหัสไฟล์ ซึ่งจะทำให้สามารถกู้คืนไฟล์ของผู้ใช้ที่ลืมรหัสผ่านได้",
    "Recovery key password" : "รหัสผ่านสำหรับรหัสกู้คืน",
    "Repeat recovery key password" : "ใส่รหัสผ่านของคีย์การกู้คืนอีกครั้ง",
    "Change recovery key password:" : "เปลี่ยนรหัสผ่านของคีย์การกู้คืน:",
    "Old recovery key password" : "รหัสผ่านของคีย์การกู้คืนเก่า",
    "New recovery key password" : "รหัสผ่านของคีย์การกู้คืนใหม่",
    "Repeat new recovery key password" : "ใส่รหัสผ่านของคีย์การกู้คืนใหม่อีกครั้ง",
    "Change Password" : "เปลี่ยนรหัสผ่าน",
    "Your private key password no longer matches your log-in password." : "รหัสผ่านคีย์ส่วนตัวของคุณ ไม่ตรงกับรหัสผ่านที่ใช้เข้าสู่ระบบของคุณอีกต่อไป",
    "Set your old private key password to your current log-in password:" : "ตั้งรหัสผ่านคีย์ส่วนตัวเก่าของคุณเป็นรหัสผ่านเข้าสู่ระบบปัจจุบันของคุณ:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "ถ้าคุณลืมรหัสผ่านเก่าของคุณ คุณสามารถขอให้ผู้ดูแลระบบกู้คืนไฟล์ของคุณ",
    "Old log-in password" : "รหัสผ่านเข้าสู่ระบบเดิม",
    "Current log-in password" : "รหัสผ่านเข้าสู่ระบบปัจจุบัน",
    "Update Private Key Password" : "อัปเดตรหัสผ่านคีย์ส่วนตัว",
    "Enable password recovery:" : "เปิดใช้งานการกู้คืนด้วยรหัสผ่าน:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "การเปิดใช้งานตัวเลือกนี้จะช่วยให้คุณสามารถเข้าถึงไฟล์ของคุณที่เข้ารหัสไว้ ในกรณีที่คุณลืมรหัสผ่าน",
    "Enabled" : "เปิดใช้งาน",
    "Disabled" : "ปิดใช้งาน",
    "The share will expire on %s." : "การแชร์จะหมดอายุในวันที่ %s",
    "Cheers!" : "ไชโย!"
},
"nplurals=1; plural=0;");
